function plot_circle(x,y,R,linestyle,facecolor,N)
% same as plot(x,y,'ko'), but plots small circles of radius R
% at each x,y point. Fully vectorized.
% Example: plot_circle([1 2 3 4], [4 5 5 6],[0.1 0.1 0.5 0.2])
% 
% D.Vamvatsikos
% Updated: 8/Oct/05

if nargin<6 N=12; end
if nargin<5 facecolor=''; end
if nargin<4 linestyle='k-'; end
if nargin<3 R=repmat(1,size(x)); 
elseif length(R)==1 R=repmat(R,size(x));    
elseif length(R)~=length(x) 
    error('R should be same length as x,y or scalar'); 
end

if length(x)~=length(y) error('x,y should be same lengths'); end
%keyboard

% use parametric form of circle
theta = linspace(0,2*pi,N)';     
tx = repmat(cos(theta),1,length(x));                   
ty = repmat(sin(theta),1,length(x));                   

newx=repmat(x,N,1)+repmat(R,N,1).*tx;
newy=repmat(y,N,1)+repmat(R,N,1).*ty;

if isempty(facecolor)
    plot(newx,newy,linestyle)
else 
    fill(newx,newy,facecolor)
end

