function plot_circular_arc(x,y,R,starttheta,endtheta,linestyle,edgecolor,N)
% same as plot(x,y,'ko'), but plots small circles of radius R
% at each x,y point. Fully vectorized, except for starttheta and endtheta
% that must be the same for all arcs.
% Example: plot_circular_arc([1 2 3 4], [4 5 5 6],[0.1 0.1 0.5 0.2],0,270)
% 
% theta values in degrees! Only a single value allowed for each of
% endtheta,starttheta!
% linestyle is '-', '--',':' or '.-', without any color designation
% color is defined directly by edgecolor.
% no filling (face) color is allowed. It looks weird for open arcs as the
% end is connected to the start by a straight line.



% Created 13/Apr/2009, Copyright (c) D.Vamvatsikos
%       Based on plot_circle.m

if nargin<8 N=12; end
if nargin<7 edgecolor='k'; end
if nargin<6 linestyle='-'; end
if nargin<5 endtheta=360;  end
if nargin<4 starttheta=0;  end
if nargin<3 R=repmat(1,size(x)); 
elseif length(R)==1 R=repmat(R,size(x));    
elseif length(R)~=length(x) 
    error('R should be same length as x,y or scalar'); 
end

if length(x)~=length(y) error('x,y should be same lengths'); end
%keyboard

% use parametric form of circle
theta = linspace(starttheta*pi/180,endtheta*pi/180,N)';     
tx = repmat(cos(theta),1,length(x));                   
ty = repmat(sin(theta),1,length(x));                   

newx=repmat(x,N,1)+repmat(R,N,1).*tx;
newy=repmat(y,N,1)+repmat(R,N,1).*ty;

plot(newx,newy,linestyle,'color',edgecolor)
   
